@@ -56,7 +56,7 @@ use Params::Util qw{_CODE _INSTANCE};
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '2.101';
+	$VERSION = '2.102';
 }
 
 =pod
@@ -118,7 +118,7 @@ See the main L<SUPPORT|Test::Inline/SUPPORT> section.
 
 =head1 AUTHOR
 
-Adam Kennedy <cpan@ali.as>, L<http://ali.as/>
+Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
